# Contributors Code of Conduct

We as members and contributors encourage participation in our community to be as constructive as possible.

We wish to act and interact in ways that contribute to an open community, considerate, courteous and respectful of everyone.

Community moderators may remove, edit, or reject contributions that are not aligned to this Code of Conduct.
